%fresnel_equations
% Plots the reflection and transmission amplitude coefficients for
% electromagnetic waves incident upon an interface between two isotropic
% media of differing refractive indices. The coefficients for reflected and
% transmitted power are also computed.
%
% LAST UPDATED by Andy French Nov 2015

function fresnel_equations

%%%% INPUTS %%%%

%Define refractive indices
n1 = 2;
n2 = 1;

%Define relative permeabilities (unity unless material is magnetic. Iron
%has a mu of about 5000, ferrite 640, nickel 100.)
mu1 = 1;
mu2 = 1;

%Numbers of data points
N = 1000;

%Fontsize
fsize = 18;

%%%%%%%%%%%%%%%%

%Define a range of incidence angles /radians
theta_i = linspace( 0, pi/2, N );

%Calculate reflection and transmission coefficients
[rp,tp] = fresnel_p(n1,n2,mu1,mu2,theta_i);
[rs,ts] = fresnel_s(n1,n2,mu1,mu2,theta_i);
[Rp,Tp] = power_coefficients(rp);
[Rs,Ts] = power_coefficients(rs);

%Calculate critical and Brewster angles
theta_c = critical_angle( n1,n2 );
theta_b = brewster_angle( n1,n2 );

%Plot graphs
figure('color',[1 1 1],'name','Fresnel Equations');

%Amplitude coefficients
plot( theta_i*180/pi, rp,'r-', theta_i*180/pi, rs,'b-', theta_i*180/pi, tp,'r--', theta_i*180/pi, ts,'b--' );
legend('r P','r S','t P','t S','fontsize',fsize,'location','best');
xlim([0,90]);
ylim([-1,1]);
grid on;
title({['Fresnel Equations: n_1 = ',num2str(n1),', n_2 = ',num2str(n2)],...
    ['Critical angle = ',num2str(theta_c*180/pi),...
    '^o, Brewster angle = ',num2str(theta_b*180/pi),'^o']},'fontsize',fsize);
xlabel('Angle of incidence /degrees','fontsize',fsize);
ylabel('Amplitude coefficient','fontsize',fsize);
set(gca,'fontsize',fsize);
print(gcf,'fresnel amplitude.png','-dpng','-r300');

%Power coefficients
cla;
plot( theta_i*180/pi, Rp,'r-', theta_i*180/pi, Rs,'b-', theta_i*180/pi, Tp,'r--', theta_i*180/pi, Ts,'b--' );
legend('r P','r S','t P','t S','fontsize',fsize,'location','best');
xlim([0,90]);
ylim([0,1]);
grid on;
title({['Fresnel Equations: n_1 = ',num2str(n1),', n_2 = ',num2str(n2)],...
    ['Critical angle = ',num2str(theta_c*180/pi),...
    '^o, Brewster angle = ',num2str(theta_b*180/pi),'^o']},'fontsize',fsize);
xlabel('Angle of incidence /degrees','fontsize',fsize);
ylabel('Power coefficient','fontsize',fsize);
set(gca,'fontsize',fsize);
print(gcf,'fresnel power.png','-dpng','-r300');
close(gcf);

%%

%Compute critical angle /radians for total internal reflection
function theta_c = critical_angle( n1,n2 )
if n1>n2
    %Only get total internal reflection if you are passing into a medium of
    %lower refractive index (e.g. glass to air).
    theta_c = asin(n2/n1);
else
    %No crtical angle
    theta_c = NaN;
end

%%

%Compute Brewster's angle /radians for only (s) polarized reflected waves
function theta_b = brewster_angle( n1,n2 )
theta_b = atan(n2/n1);

%%

%Compute Fresnel equations for (p) polarized waves i.e. electric field
%vector is in the same plane as the wave vectors of incident, reflected and
%transmitted waves. Output are amplitude reflection (r) and transmission
%(t) coefficients. n1, n2 are the refractive indices, mu1,mu2 are the
%relative permeabilities. Note n = sqrt( epsilon x mu ) where epsilon is
%the relative permittivity.
function [r,t] = fresnel_p(n1,n2,mu1,mu2,theta_i)

%Determine transmitted (i.e. refracted) ray angle using Snell's Law
theta_t = asin( sin(theta_i)*n1/n2 );

%Determine reflection and transmission coefficients
r = ( -(n2/mu2)*cos(theta_i) + (n1/mu1)*cos(theta_t) )./...
    ( (n1/mu1)*cos(theta_t) + (n2/mu2)*cos(theta_i) );
t = 2*(n1/mu1)*cos(theta_i)./...
    ( (n1/mu1)*cos(theta_t) + (n2/mu2)*cos(theta_i) );

%Ignore any transmission beyond the critical angle
if n1>n2
    r( theta_i > asin( n2/n1 ) ) = 1;
    t( theta_i > asin( n2/n1 ) ) = 0;
end;


%%

%Compute Fresnel equations for (s) polarized waves i.e. electric field
%vector is perpendicular to the plane as the wave vectors of incident, reflected and
%transmitted waves. Output are amplitude reflection (r) and transmission
%(t) coefficients. n1, n2 are the refractive indices, mu1,mu2 are the
%relative permeabilities. Note n = sqrt( epsilon x mu ) where epsilon is
%the relative permittivity.
function [r,t] = fresnel_s(n1,n2,mu1,mu2,theta_i)

%Determine transmitted (i.e. refracted) ray angle using Snell's Law
theta_t = asin( sin(theta_i)*n1/n2 );

%Determine reflection and transmission coefficients
r = ( (n1/mu1)*cos(theta_i) - (n2/mu2)*cos(theta_t) )./...
    ( (n1/mu1)*cos(theta_i) + (n2/mu2)*cos(theta_t) );
t = 2*(n1/mu1)*cos(theta_i)./...
    ( (n1/mu1)*cos(theta_i) + (n2/mu2)*cos(theta_t) );

%Ignore any transmission beyond the critical angle
if n1>n2
    r( theta_i > asin( n2/n1 ) ) = 1;
    t( theta_i > asin( n2/n1 ) ) = 0;
end;

%%

%Compute power reflection coefficients
function [R,T] = power_coefficients(r)
R = abs(r).^2;
T = 1 - R;

%End of code