%polarization
% Function which plots the x and y components of an electric field vector.
% z is assumed to be the direction of propagation, so the electric field
% oscillates in the x,y plane.
% The state of polarization is defined by the Jones Vector, which relates
% the phases betwen x and y components of the electric field. Depending on
% the phase shift, the elctric field will be linearly, circularly or
% elliptically polarized.
%
% Reference: Woan, The Cambridge Handbook of Physics Formulas pp170.

function polarization

%%%%% INPUTS %%%%%

%Define Jones vector from parameters of polarization

%Define maximum y and x field strengths /Vm^-1
E0x = 1;
E0y = 2;

%Define phase shift /degrees between x and y electric field vectors
delta = 60;

%Define Jones matrices which determine how polarization changes when light
%passes through a polarizer. (e.g. polaroid, Fresnel rhomb etc).

%Linear polariser in x direction
J = [1,0;0,0];

%Linear polariser in y direction
J = [0,0;0,1];

%Linear polariser at 45 degrees
J = 0.5*[1,1;1,1];

%Linear polariser at -45 degrees
J = 0.5*[1,-1;-1,1];

%Right circular polariser
J = 0.5*[1,i;-i,1];

%Left circular polariser
J = 0.5*[1,-i;i,1];

%Quarter wave plate ('fast x')
J = exp(i*pi/4)*[1,0;0,i];

%Quarter wave plate ('fast y')
J = exp(i*pi/4)*[1,0;0,-i];

%No polariser added
J = [1,0;0,1];

%%%%%%%%%%% Choose polariser %%%%%%%%%%%

%Linear polariser at -45 degrees
J = 0.5*[1,-1;-1,1];

%Define font size for graphs
fsize = 18;

%Define number of electric field oscillation
num_oscillations = 2;

%Number of phase samples
N = 1000;

%Time /s for one oscillation (for animation!)
T = 1;

%%

%Work out sample numbers corresponding to 90 degrees of
%phase. Characters will be plotted at these values to indicate the
%direction of travel round the polarisation ellipse
N_90 = round( 0.25*N/num_oscillations);

%Work out time delay between each phase value for animation
dt = T*num_oscillations/N;

%Normalize electric field stength
E0xn = E0x/sqrt(E0x.*conj(E0x)+ E0y.*conj(E0y));
E0yn = E0y/sqrt(E0x.*conj(E0x)+ E0y.*conj(E0y));

%Define input electric field phasor (phase = k*z - omega*t radians)
theta = linspace(0,2*pi*num_oscillations,1000);
Ei = [E0xn*exp(-i*theta) ; E0yn*exp(i*delta*pi/180)*exp(-i*theta) ];

%Calculate angle of tilt of polarization ellipse /radians
alpha = 0.5*atan2( 2*E0x*E0y*cos(delta*pi/180),E0x^2-E0y^2 );

%Define output electric field phasor following application of polariser
Eo = J*Ei;

%Set up figure
fig = figure('color',[1 1 1],'name','Polarization','renderer','painters');
warning off

%Plot input electric field components vs phase
plot( theta*180/pi, real(Ei(1,:)), theta*180/pi, real(Ei(2,:)) );
xlabel('phase /degrees','fontsize',fsize);
ylabel('Normalized Electric field strength','fontsize',fsize)
title({'Input electric field polarization',...
    ['E0x : E0y = ',num2str(E0x),' : ',num2str(E0y),...
    ', phase shift = ',num2str(delta),' ^o'] },'fontsize',fsize);
legend('Ex','Ey','fontsize',fsize)
xlim([0,max(theta*180/pi)]);
ylim([-1,1])
grid on;
set(gca,'fontsize',fsize);
print( fig, 'input electric field vs phase.png','-dpng','-r300' );

%Plot output electric field components vs phase
cla;
plot( theta*180/pi, real(Eo(1,:)), theta*180/pi, real(Eo(2,:)) );
xlabel('phase /degrees','fontsize',fsize);
ylabel('Normalized Electric field strength','fontsize',fsize)
title('Output electric field polarization','fontsize',fsize);
legend('Ex','Ey','fontsize',fsize)
xlim([0,max(theta*180/pi)]);
ylim([-1,1])
grid on;
set(gca,'fontsize',fsize);
print( fig, 'output electric field vs phase.png','-dpng','-r300' );
cla;

%Plot Ex vs Ey for input and output
plot( real(Ei(1,:)), real(Ei(2,:)),'b-', real(Eo(1,:)), real(Eo(2,:)),'r-' );
axis equal;
axis manual;
hold on;
x = linspace(-1,1,1000);
y = x*tan(alpha);
plot(x,y,'b--');
p=plot( real(Ei(1,1)), real(Ei(2,1)),'bo' );
p90=plot( real(Ei(1,N_90)), real(Ei(2,N_90)),'b*' );
q=plot( real(Eo(1,1)), real(Eo(2,1)),'ro' );
q90=plot( real(Eo(1,N_90)), real(Eo(2,N_90)),'r*' );
ylim([-1,1]);
xlim([-1,1]);
xlabel('Normalized Electric field strength','fontsize',fsize)
ylabel('Normalized Electric field strength','fontsize',fsize)
title({'Input electric field polarization',...
    ['E0x : E0y = ',num2str(E0x),' : ',num2str(E0y),...
    ', phase shift = ',num2str(delta),' ^o'] },'fontsize',fsize);
legend({'Input','Output'},'fontsize',fsize );
grid on
print( fig, 'input vs output electric field.png','-dpng','-r300' );

%Plot an animated Ex vs Ey for input and output
delete(p90); 
delete(q90);
stop = '';
pline = plot( [0,real(Ei(1,1))],[0,real(Ei(2,1))],'b-' );
qline = plot( [0,real(Eo(1,1))],[0,real(Eo(2,1))],'r-' );
n=1;
while isempty(stop)
    
    %Increment phase value step
    n=n+1;
    if n>N
        n=1;
    end
    
    %Update Ex vs Ey plot with current values
    set(p,'xdata', real(Ei(1,n)), 'ydata', real(Ei(2,n)) );
    set(pline,'xdata', [0,real(Ei(1,n))], 'ydata',  [0,real(Ei(2,n))] );
    set(q,'xdata', real(Eo(1,n)), 'ydata',  real(Eo(2,n)) );
    set(qline,'xdata', [0,real(Eo(1,n))],  'ydata', [0,real(Eo(2,n))] );
    
    %After flushing graphics buffer, pause for dt seconds to enable smooth animation
    drawnow;
    pause(dt);
    
    %Check for a key press
    stop = get( fig,'currentkey');
end
close(gcf);

%End of code
